@@ -10,7 +10,7 @@ use crate::config::{Config, Delimiter};
 use crate::select::SelectColumns;
 use crate::util;
 use crate::CliResult;
-use indicatif::ProgressBar;
+use indicatif::{ProgressBar, ProgressDrawTarget};
 use serde::Deserialize;
 
 static USAGE: &str = "
@@ -87,11 +87,12 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
     let mut output_headers_written = false;
 
     // prep progress bar
-    let mut record_count: u64 = 0;
-    let progress = ProgressBar::new(record_count);
+    let progress = ProgressBar::new(0);
     if !args.flag_quiet {
-        record_count = util::count_rows(&rconfig);
+        let record_count = util::count_rows(&rconfig);
         util::prep_progress(&progress, record_count);
+    } else {
+        progress.set_draw_target(ProgressDrawTarget::hidden());
     }
 
     while rdr.read_byte_record(&mut record)? {
