@@ -67,11 +67,8 @@ stats options:
     -j, --jobs <arg>       The number of jobs to run in parallel.
                            This works only when the given CSV has an index.
                            Note that a file handle is opened for each job.
-                           When set to '0', the number of jobs is set to the
-                           number of CPUs detected divided by 3.
-                           When set to '-1', the number of jobs is set to the
+                           When not set, the number of jobs is set to the
                            number of CPUs detected.
-                           [default: 0]
 
 Common options:
     -h, --help             Display this message
@@ -95,7 +92,7 @@ pub struct Args {
     pub flag_nulls: bool,
     pub flag_dates: bool,
     pub flag_nullcount: bool,
-    pub flag_jobs: usize,
+    pub flag_jobs: Option<usize>,
     pub flag_output: Option<String>,
     pub flag_no_headers: bool,
     pub flag_delimiter: Option<Delimiter>,
@@ -108,8 +105,12 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
     let (headers, stats) = match args.rconfig().indexed()? {
         None => args.sequential_stats(),
         Some(idx) => {
-            if args.flag_jobs == 1 {
-                args.sequential_stats()
+            if let Some(num_jobs) = args.flag_jobs {
+                if num_jobs == 1 {
+                    args.sequential_stats()
+                } else {
+                    args.parallel_stats(idx)
+                }
             } else {
                 args.parallel_stats(idx)
             }
@@ -153,10 +154,10 @@ impl Args {
         let mut rdr = self.rconfig().reader()?;
         let (headers, sel) = self.sel_headers(&mut rdr)?;
 
-        let chunk_size = util::chunk_size(idx.count() as usize, self.njobs());
+        let chunk_size = util::chunk_size(idx.count() as usize, util::njobs(self.flag_jobs));
         let nchunks = util::num_of_chunks(idx.count() as usize, chunk_size);
 
-        let pool = ThreadPool::new(self.njobs());
+        let pool = ThreadPool::new(util::njobs(self.flag_jobs));
         let (send, recv) = channel::bounded(0);
         for i in 0..nchunks {
             let (send, args, sel) = (send.clone(), self.clone(), sel.clone());
@@ -173,7 +174,7 @@ impl Args {
 
     pub fn stats_to_records(&self, stats: Vec<Stats>) -> Vec<csv::StringRecord> {
         let mut records: Vec<_> = repeat(csv::StringRecord::new()).take(stats.len()).collect();
-        let pool = ThreadPool::new(self.njobs());
+        let pool = ThreadPool::new(util::njobs(self.flag_jobs));
         let mut results = vec![];
         for mut stat in stats {
             let (send, recv) = channel::bounded(0);
@@ -223,14 +224,6 @@ impl Args {
             .select(self.flag_select.clone())
     }
 
-    fn njobs(&self) -> usize {
-        if self.flag_jobs == 0 {
-            util::num_cpus()
-        } else {
-            self.flag_jobs
-        }
-    }
-
     #[inline]
     fn new_stats(&self, record_len: usize) -> Vec<Stats> {
         repeat(Stats::new(WhichStats {
@@ -416,54 +409,43 @@ impl Stats {
         let empty = || "".to_owned();
 
         pieces.push(self.typ.to_string());
-        match self.sum.as_ref().and_then(|sum| sum.show(typ)) {
-            Some(sum) => {
-                pieces.push(sum);
-            }
-            None => {
-                pieces.push(empty());
-            }
+        if let Some(sum) = self.sum.as_ref().and_then(|sum| sum.show(typ)) {
+            pieces.push(sum);
+        } else {
+            pieces.push(empty());
         }
-        match self.minmax.as_ref().and_then(|mm| mm.show(typ)) {
-            Some(mm) => {
-                pieces.push(mm.0);
-                pieces.push(mm.1);
-            }
-            None => {
-                pieces.push(empty());
-                pieces.push(empty());
-            }
+
+        if let Some(mm) = self.minmax.as_ref().and_then(|mm| mm.show(typ)) {
+            pieces.push(mm.0);
+            pieces.push(mm.1);
+        } else {
+            pieces.push(empty());
+            pieces.push(empty());
         }
-        match self.minmax.as_ref().and_then(|mm| mm.len_range()) {
-            Some(mm) => {
-                pieces.push(mm.0);
-                pieces.push(mm.1);
-            }
-            None => {
-                pieces.push(empty());
-                pieces.push(empty());
-            }
+
+        if let Some(mm) = self.minmax.as_ref().and_then(TypedMinMax::len_range) {
+            pieces.push(mm.0);
+            pieces.push(mm.1);
+        } else {
+            pieces.push(empty());
+            pieces.push(empty());
         }
 
         if !self.typ.is_number() {
             pieces.push(empty());
             pieces.push(empty());
             pieces.push(empty());
+        } else if let Some(ref v) = self.online {
+            let mut buffer = ryu::Buffer::new();
+            pieces.push(buffer.format(v.mean()).to_owned());
+            pieces.push(buffer.format(v.stddev()).to_owned());
+            pieces.push(buffer.format(v.variance()).to_owned());
         } else {
-            match self.online {
-                Some(ref v) => {
-                    let mut buffer = ryu::Buffer::new();
-                    pieces.push(buffer.format(v.mean()).to_owned());
-                    pieces.push(buffer.format(v.stddev()).to_owned());
-                    pieces.push(buffer.format(v.variance()).to_owned());
-                }
-                None => {
-                    pieces.push(empty());
-                    pieces.push(empty());
-                    pieces.push(empty());
-                }
-            }
+            pieces.push(empty());
+            pieces.push(empty());
+            pieces.push(empty());
         }
+
         match self.median.as_mut().and_then(|v| match self.typ {
             TInteger | TFloat => v.median(),
             _ => None,
@@ -591,7 +573,6 @@ impl FieldType {
                 return TDate;
             }
         }
-
         TString
     }
 
@@ -615,7 +596,7 @@ impl Commute for FieldType {
             (TInteger, TInteger) => TInteger,
             (TDate, TDate) => TDate,
             // date data types
-            (TDateTime, TDateTime) | (TDate, TDateTime) | (TDateTime, TDate) => TDateTime,
+            (TDateTime | TDate, TDateTime) | (TDateTime, TDate) => TDateTime,
             // Null does not impact the type.
             (TNull, any) | (any, TNull) => any,
             // Integers can degrade to floats.
@@ -667,7 +648,6 @@ impl fmt::Debug for FieldType {
 }
 
 /// TypedSum keeps a rolling sum of the data seen.
-///
 /// It sums integers until it sees a float, at which point it sums floats.
 #[derive(Clone, Default)]
 struct TypedSum {
