@@ -7,11 +7,19 @@ use crate::config::{Config, Delimiter};
 use crate::CliResult;
 use docopt::Docopt;
 use indicatif::{ProgressBar, ProgressStyle};
-use log::{debug, info, log_enabled, Level};
+use log::{debug, error, info, log_enabled, Level};
 use regex::Regex;
 use serde::de::{Deserialize, DeserializeOwned, Deserializer, Error};
 use thousands::Separable;
 
+#[macro_export]
+macro_rules! regex_once_cell {
+    ($re:literal $(,)?) => {{
+        static RE: once_cell::sync::OnceCell<regex::Regex> = once_cell::sync::OnceCell::new();
+        RE.get_or_init(|| regex::Regex::new($re).unwrap())
+    }};
+}
+
 #[inline]
 pub fn num_cpus() -> usize {
     thread::available_parallelism().unwrap().get()
@@ -37,6 +45,17 @@ pub fn max_jobs() -> usize {
     }
 }
 
+pub fn njobs(flag_jobs: Option<usize>) -> usize {
+    let num_cpus = num_cpus();
+    flag_jobs.map_or(num_cpus, |jobs| {
+        if jobs == 0 || jobs > num_cpus {
+            num_cpus
+        } else {
+            jobs
+        }
+    })
+}
+
 pub fn version() -> String {
     let mut enabled_features = "".to_string();
 
@@ -106,17 +125,16 @@ pub fn show_env_vars() {
 }
 
 pub fn count_rows(conf: &Config) -> u64 {
-    match conf.indexed().unwrap() {
-        Some(idx) => idx.count(),
-        None => {
-            let mut rdr = conf.reader().unwrap();
-            let mut count = 0u64;
-            let mut record = csv::ByteRecord::new();
-            while rdr.read_byte_record(&mut record).unwrap() {
-                count += 1;
-            }
-            count
+    if let Some(idx) = conf.indexed().unwrap() {
+        idx.count()
+    } else {
+        let mut rdr = conf.reader().unwrap();
+        let mut count = 0u64;
+        let mut record = csv::ByteRecord::new();
+        while rdr.read_byte_record(&mut record).unwrap() {
+            count += 1;
         }
+        count
     }
 }
 
@@ -455,7 +473,7 @@ pub fn qsv_check_for_update(bin_name: &str) {
 
     if latest_release > &curr_version.to_string() {
         eprintln!("Update {latest_release} available. Current version is {curr_version}.",);
-        let update_job = self_update::backends::github::Update::configure()
+        match self_update::backends::github::Update::configure()
             .repo_owner("jqnatividad")
             .repo_name("qsv")
             .bin_name(bin_name)
@@ -464,17 +482,26 @@ pub fn qsv_check_for_update(bin_name: &str) {
             .no_confirm(false)
             .current_version(curr_version)
             .build()
-            .unwrap();
-
-        let update_result = update_job.update();
-        if let Ok(status) = update_result {
-            let update_status = format!(
-                "Update successful for {}: `{}`!",
-                bin_name,
-                status.version()
-            );
-            eprintln!("{update_status}");
-            info!("{update_status}");
+        {
+            Ok(update_job) => match update_job.update() {
+                Ok(status) => {
+                    let update_status = format!(
+                        "Update successful for {}: `{}`!",
+                        bin_name,
+                        status.version()
+                    );
+                    eprintln!("{update_status}");
+                    info!("{update_status}");
+                }
+                Err(e) => {
+                    eprintln!("Self update update job error: {e}");
+                    error!("Self update update job error: {e}");
+                }
+            },
+            Err(e) => {
+                eprintln!("Self update builder error: {e}");
+                error!("Self update builder error: {e}");
+            }
         };
     } else {
         eprintln!("Up to date ({curr_version})... no update required.");
@@ -488,7 +515,7 @@ pub fn safe_header_names(headers: &csv::StringRecord, check_first_char: bool) ->
     // If name starts with a number, replace it with an _ as well
     let re = Regex::new(r"[^A-Za-z0-9]").unwrap();
     let mut header_vec: Vec<String> = Vec::with_capacity(headers.len());
-    for (_i, h) in headers.iter().take(headers.len()).enumerate() {
+    for h in headers {
         let mut python_var_name = re.replace_all(h, "_").to_string();
         if check_first_char && python_var_name.as_bytes()[0].is_ascii_digit() {
             python_var_name.replace_range(0..1, "_");
